package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Feb 21, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type PluginConfig struct {
InputFile string
OuputDirectory string
CreateOutputDirectory bool
OutputManifest string
DockerTargetDirectory string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.